@@ -1,5 +1,6 @@
 import math
 import time
+import sys
 
 from paramsurvey import stats
 
@@ -34,7 +35,7 @@ def test_record_wallclock():
     assert raw_stats['foo'][0] > duration * 0.9
 
 
-def testS_record_iotime():
+def test_record_iotime():
     raw_stats = {}
     duration = 0.1
     start = time.time()
@@ -46,3 +47,22 @@ def testS_record_iotime():
     assert 'io' in raw_stats
     assert len(raw_stats['io']) == 1
     assert raw_stats['io'][0] >= duration*2
+
+
+def test_percentiles():
+    raw_stats = {'default': [0.1, 0.2, 0.3, 0.4, 0.5, 0.6, 0.7, 0.8, 0.9, 1.0]}
+    s = stats.PerfStats(raw_stats)
+    s.print_percentile('default')
+    s.print_percentiles('default')  # empty
+    s.print_percentiles(None)  # same as first
+    s.print_percentiles(None, file=sys.stderr)  # same as first, but on stderr
+
+
+def test_histograms():
+    raw_stats = {'default': [0.1, 0.2, 0.2, 0.2, 0.2, 0.6, 0.7, 0.8, 0.9, 1.0]}
+
+    s = stats.PerfStats(raw_stats)
+    s.print_histogram('default')
+    s.print_histograms('default')  # empty
+    s.print_histograms(None)  # same as first
+    s.print_histograms(None, file=sys.stderr)  # same as first, but on stderr
