@@ -1,5 +1,6 @@
 import pytest
 import paramsurvey
+from paramsurvey import utils
 
 
 def test_flatten_results():
@@ -17,3 +18,14 @@ def test_flatten_results():
     normal[1]['result']['a'] = 1
     with pytest.raises(ValueError):
         flat = paramsurvey.flatten_results(normal)
+
+
+def test_make_subdir_name():
+    ret = utils.make_subdir_name(100)
+    assert len(ret) == 4
+
+    ret = utils.make_subdir_name(100, prefix='prefix')
+    assert len(ret) == 8
+
+    with pytest.raises(Exception):
+        ret = utils.make_subdir_name(0)
